@@ -12,7 +12,7 @@
 #include "kgrscene.h"
 #include "kgrselector.h"
 // KGoldrunner loads and plays .ogg files and requires OpenAL + SndFile > v0.21.
-// Fallback to Phonon by the KgSound library does not give good results.
+// Fallback to Phonon by the KGameSound library does not give good results.
 #include <libkdegames_capabilities.h>
 #ifdef KGAUDIO_BACKEND_OPENAL
     #include "kgrsounds.h"
@@ -43,7 +43,6 @@
 #include <QFileInfo>
 #include <QRandomGenerator>
 
-#include <kwidgetsaddons_version.h>
 #include <KConfigGroup>
 #include <KGuiItem>
 #include <KSharedConfig>
@@ -329,7 +328,7 @@ void KGrGame::editActions (const int action)
         level     = lev;
 
         //qCDebug(KGOLDRUNNER_LOG) << "Saving to KConfigGroup";
-        KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+        KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
         gameGroup.writeEntry (QStringLiteral("GamePrefix"), prefix);
         gameGroup.writeEntry (QStringLiteral("Level_") + prefix, level);
         gameGroup.sync();		// Ensure that the entry goes to disk.
@@ -367,7 +366,7 @@ void KGrGame::editToolbarActions (const int action)
 void KGrGame::settings (const int action)
 {
     // TODO - Bad   - Configure Keys does not pause a demo. IDW
-    KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+    KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
     bool onOff = false;
     switch (action) {
     case PLAY_SOUNDS:
@@ -429,7 +428,7 @@ void KGrGame::initGame()
 
     // Get the most recent collection and level that was played by this user.
     // If he/she has never played before, set it to Tutorial, level 1.
-    KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+    KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
     QString prevGamePrefix = gameGroup.readEntry ("GamePrefix", "tute");
     int prevLevel          = gameGroup.readEntry (QLatin1String("Level_") + prevGamePrefix, 1);
 
@@ -659,7 +658,7 @@ void KGrGame::startInstantReplay()
 void KGrGame::replayLastLevel()
 {
     // Replay the last game and level completed by the player.
-    KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+    KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
     QString lastPrefix = gameGroup.readEntry ("LastGamePrefix", "");
     int lastLevel      = gameGroup.readEntry ("LastLevel",      -1);
 
@@ -927,7 +926,7 @@ bool KGrGame::playLevel (const Owner fileOwner, const QString & prefix,
 
     // If we are starting a new level, save it in the player's config file.
     if (newLevel && (level != 0)) {	// But do not save the "ENDE" level.
-        KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+        KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
         gameGroup.writeEntry ("GamePrefix", prefix);
         gameGroup.writeEntry (QStringLiteral("Level_") + prefix, level);
         gameGroup.sync();		// Ensure that the entry goes to disk.
@@ -1017,7 +1016,7 @@ void KGrGame::endLevel (const int result)
         saveRecording (QStringLiteral("rec_"));
 
         // Save the game and level, for use in the REPLAY_LAST action.
-        KConfigGroup gameGroup (KSharedConfig::openConfig (), "KDEGame");
+        KConfigGroup gameGroup (KSharedConfig::openConfig (), QStringLiteral("KDEGame"));
         gameGroup.writeEntry ("LastGamePrefix", prefix);
         gameGroup.writeEntry ("LastLevel",      level);
         gameGroup.sync();		// Ensure that the entry goes to disk.
@@ -1215,7 +1214,7 @@ bool KGrGame::inEditMode()
 void KGrGame::toggleSoundsOnOff (const int action)
 {
     const char * setting = (action == PLAY_SOUNDS) ? "Sound" : "StepSounds";
-    KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+    KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
     bool soundOnOff = gameGroup.readEntry (setting, false);
     soundOnOff = (! soundOnOff);
     gameGroup.writeEntry (setting, soundOnOff);
@@ -1412,11 +1411,7 @@ void KGrGame::kbControl (const int dirn, const bool pressed)
         // Halt the game while a message is displayed.
         freeze (ProgramPause, true);
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         switch (KMessageBox::questionTwoActions (view,
-#else
-        switch (KMessageBox::questionYesNo (view, 
-#endif
                 i18n ("You have pressed a key that can be used to control the "
                 "Hero. Do you want to switch automatically to keyboard "
                 "control? Pointer control is easier to use in the long term "
@@ -1426,21 +1421,13 @@ void KGrGame::kbControl (const int dirn, const bool pressed)
                 KGuiItem (i18n ("Stay in &Mouse Mode")),
                 i18n ("Keyboard Mode")))
         {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         case KMessageBox::PrimaryAction:
-#else
-        case KMessageBox::Yes:
-#endif
         case KMessageBox::Ok:
         case KMessageBox::Continue:
             settings (KEYBOARD);
             Q_EMIT setToggle ("keyboard_mode", true);	// Adjust Settings menu.
             break;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         case KMessageBox::SecondaryAction:
-#else
-        case KMessageBox::No:
-#endif
         case KMessageBox::Cancel:
             break;
         }
@@ -1580,11 +1567,7 @@ bool KGrGame::selectSavedGame (int & selectedGame, int & selectedLevel)
         }
         if (index >= 0) {
             selectedGame  = index;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            selectedLevel = loadedData.midRef (28, 3).toInt();
-#else
             selectedLevel = QStringView(loadedData).mid(28, 3).toInt();
-#endif
             result = true;
         }
         else {
@@ -2136,7 +2119,7 @@ bool KGrGame::initRecordingData (const Owner fileOwner, const QString & prefix,
         recording->speed       = timeScale;
         recording->controlMode = controlMode;
         recording->keyOption   = holdKeyOption;
-        recording->content [0] = 0xff;
+        recording->content [0] = static_cast<char>(0xff);
     }
     return true;
 }
